==> 0.0.7.tar.gz: example/lib/page_user.dart <==
import 'package:flutter/material.dart';
import 'package:netmera_flutter_sdk/Netmera.dart';
import 'package:netmera_flutter_sdk/NetmeraUser.dart';
import 'model/MyNetmeraUser.dart';

///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class UserPage extends StatefulWidget {
  @override
  _UserPageState createState() => _UserPageState();
}

class _UserPageState extends State<UserPage> {
  TextEditingController userController = TextEditingController();
  TextEditingController nameController = TextEditingController();
  TextEditingController surnameController = TextEditingController();
  TextEditingController emailController = TextEditingController();
  TextEditingController msisdnController = TextEditingController();
  String _selectedGender = NetmeraUser.GENDER_NOT_SPECIFIED.toString();

  updateUser() {
    MyNetmeraUser user = new MyNetmeraUser();
    user.setUserId(userController.text);
    user.setName(nameController.text);
    user.setSurname(surnameController.text);
    user.setEmail(emailController.text);
    user.setMsisdn(msisdnController.text);
    user.setGender(int.parse(_selectedGender));
    user.setHairColor(7);
    Netmera.updateUser(user);
  }

  List<DropdownMenuItem<String>> getGenderList() {
    List<DropdownMenuItem<String>> items = new List();
    items.add(
        new DropdownMenuItem(value: NetmeraUser.GENDER_NOT_SPECIFIED.toString(), child: new Text("NOT SPECIFIED")));
    items.add(new DropdownMenuItem(value: NetmeraUser.GENDER_MALE.toString(), child: new Text("MALE")));
    items.add(new DropdownMenuItem(value: NetmeraUser.GENDER_FEMALE.toString(), child: new Text("FEMALE")));
    return items;
  }

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Padding(
            padding: const EdgeInsets.only(left: 50.0, right: 50.0),
            child: TextField(
              controller: userController,
              decoration: InputDecoration(labelText: 'User (Optional)'),
            ),
          ),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: TextField(
                controller: nameController,
                decoration: InputDecoration(labelText: 'Name (Optional)'),
              )),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: TextField(
                controller: surnameController,
                decoration: InputDecoration(labelText: 'Surname (Optional)'),
              )),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: TextField(
                controller: emailController,
                decoration: InputDecoration(labelText: 'Email (Optional)'),
              )),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: TextField(
                controller: msisdnController,
                decoration: InputDecoration(labelText: 'Msisdn (Optional)'),
              )),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: Row(children: [
                Text('Gender (Optional)'),
                Padding(
                    padding: const EdgeInsets.only(left: 10.0),
                    child: DropdownButton(
                        value: _selectedGender,
                        items: getGenderList(),
                        onChanged: (val) {
                          setState(() {
                            _selectedGender = val;
                          });
                        }))
              ])),
          Container(
            margin: EdgeInsets.only(top: 30),
            child: RaisedButton(
              child: Text('Update User'),
              onPressed: updateUser,
            ),
          )
        ],
      ),
    );
  }
}

==> 1.0.4.tar.gz: example/lib/page_user.dart <==
import 'package:flutter/material.dart';
import 'package:netmera_flutter_sdk/Netmera.dart';
import 'package:netmera_flutter_sdk/NetmeraUser.dart';
import 'model/MyNetmeraUser.dart';

///
/// Copyright (c) 2019 Inomera Research.
/// Author Burak Soykal
///
class UserPage extends StatefulWidget {
  @override
  _UserPageState createState() => _UserPageState();
}

class _UserPageState extends State<UserPage> {
  TextEditingController userController = TextEditingController();
  TextEditingController nameController = TextEditingController();
  TextEditingController surnameController = TextEditingController();
  TextEditingController emailController = TextEditingController();
  TextEditingController msisdnController = TextEditingController();
  String _selectedGender = NetmeraUser.GENDER_NOT_SPECIFIED.toString();

  updateUser() {
    MyNetmeraUser user = new MyNetmeraUser();
    user.setUserId(userController.text);
    user.setName(nameController.text);
    user.setSurname(surnameController.text);
    user.setEmail(emailController.text);
    user.setMsisdn(msisdnController.text);
    user.setGender(int.parse(_selectedGender));
    user.setHairColor(7);
    Netmera.updateUser(user);
  }

  List<DropdownMenuItem<String>> getGenderList() {
    List<DropdownMenuItem<String>> items = new List();
    items.add(new DropdownMenuItem(
        value: NetmeraUser.GENDER_NOT_SPECIFIED.toString(),
        child: new Text("NOT SPECIFIED")));
    items.add(new DropdownMenuItem(
        value: NetmeraUser.GENDER_MALE.toString(), child: new Text("MALE")));
    items.add(new DropdownMenuItem(
        value: NetmeraUser.GENDER_FEMALE.toString(),
        child: new Text("FEMALE")));
    return items;
  }

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      child: Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          Padding(
            padding: const EdgeInsets.only(left: 50.0, right: 50.0),
            child: TextField(
              controller: userController,
              decoration: InputDecoration(labelText: 'User (Optional)'),
            ),
          ),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: TextField(
                controller: nameController,
                decoration: InputDecoration(labelText: 'Name (Optional)'),
              )),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: TextField(
                controller: surnameController,
                decoration: InputDecoration(labelText: 'Surname (Optional)'),
              )),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: TextField(
                controller: emailController,
                decoration: InputDecoration(labelText: 'Email (Optional)'),
              )),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: TextField(
                controller: msisdnController,
                decoration: InputDecoration(labelText: 'Msisdn (Optional)'),
              )),
          Padding(
              padding: const EdgeInsets.only(left: 50.0, right: 50.0),
              child: Row(children: [
                Text('Gender (Optional)'),
                Padding(
                    padding: const EdgeInsets.only(left: 10.0),
                    child: DropdownButton(
                        value: _selectedGender,
                        items: getGenderList(),
                        onChanged: (val) {
                          setState(() {
                            _selectedGender = val;
                          });
                        }))
              ])),
          Container(
            margin: EdgeInsets.only(top: 30),
            child: RaisedButton(
              child: Text('Update User'),
              onPressed: updateUser,
            ),
          )
        ],
      ),
    );
  }
}
